@@ -86,18 +86,20 @@ using namespace std;
 // Mongoose web server
 struct mg_server *server = (mg_server *)NULL;
 void *poll_server(void *);
-void start_web_server();
+int  start_web_server();
 void close_server();
-bool get_next_port_number();
+char *mongoose_msg;
+string mongoose_msgs;
 
-int flmsg_webserver_portnbr = 8080;
-char flmsg_webserver_szportnbr[5];
+int srvr_portnbr = 8080;
+char sz_srvr_portnbr[6];
 //------------------------------------------------------------------------------
 
 const char *options[] = {\
 "flmsg unique options",
 "--help",
 "--version",
+"--server-port\tstarting port number for forms web server [8080]",
 "--flmsg-dir\tfull-path-name-of-folder for all FLMSG folders",
 "--auto-dir\tfull-path-name-of-folder for autosend files",
 "\tauto-dir, flmsg-dir can be separate and unique",
@@ -1932,6 +1934,19 @@ void after_start(void *)
 	} else
 		default_form();
 
+	// Check to see what io mode FLDIGI is in.
+	std::string io_mode = get_io_mode();
+	int flag = 0;
+	if(!io_mode.empty()) {
+		flag = strncmp(io_mode.c_str(), "ARQ", 3);
+		if(flag != 0) {
+			flag = fl_choice2(_("KISS interface active! Switch FLDIGI to ARQ?"),
+			   _("No"), _("Yes"), NULL);
+			if(flag == 1)
+				enable_arq();
+		}
+	}
+
 #ifdef __APPLE__
 	fl_open_callback(open_callback);
 #endif
@@ -2050,10 +2065,9 @@ int main(int argc, char *argv[])
 
 	checkdirectories();
 	load_custom_menu();
-	if (!get_next_port_number()) return 1;
 
 	string debug_file = FLMSG_dir;
-	debug_file.append("debug_log_").append(flmsg_webserver_szportnbr).append(".txt");
+	debug_file.append("debug_log_").append(sz_srvr_portnbr).append(".txt");
 	debug::start(debug_file.c_str());
 
 	LOG_INFO("FLMSG_dir        %s", FLMSG_dir.c_str());
@@ -2073,10 +2087,14 @@ int main(int argc, char *argv[])
 	LOG_INFO("Transfer dir     %s", XFR_dir.c_str());
 	LOG_INFO("FLMSG_temp_dir   %s", FLMSG_temp_dir.c_str());
 
-	LOG_INFO("%s", parse_info.c_str());
+	if (!parse_info.empty())
+		LOG_INFO("%s", parse_info.c_str());
 
 	start_web_server();
 
+	if (!mongoose_msgs.empty())
+		LOG_INFO("%s", mongoose_msgs.c_str());
+
 	if (printme) {
 #ifdef __APPLE_
 		fl_open_display();
@@ -2394,8 +2412,7 @@ void set_config_values()
 	txt_socket_addr->value(progStatus.socket_addr.c_str());
 	txt_socket_port->value(progStatus.socket_port.c_str());
 
-	txt_web_addr->value("127.0.0.1");
-	txt_web_port->value(flmsg_webserver_szportnbr);
+	txt_web_port->value(sz_srvr_portnbr);
 }
 
 void cb_config_date_time()
@@ -2473,7 +2490,16 @@ int parse_args(int argc, char **argv, int& idx)
 		parse_info.append("parsed --flmsg-dir ");
 		parse_info.append(FLMSG_dir).append("\n");
 		idx++;
-		return 1;
+		return 2;
+	}
+
+	if (strstr(argv[idx], "--server-port")) {
+		idx++;
+		int port = 0;
+		if (sscanf(argv[idx], "%d", &port) == 1)
+			srvr_portnbr = port;
+		idx++;
+		return 2;
 	}
 
 	if (strstr(argv[idx], "--auto-dir")) {
@@ -2486,7 +2512,7 @@ int parse_args(int argc, char **argv, int& idx)
 		parse_info.append("parsed --autodir ");
 		parse_info.append(WRAP_auto_dir).append("\n");
 		idx++;
-		return 1;
+		return 2;
 	}
 
 	if ( argv[idx][0] == '-' )
@@ -2648,86 +2674,6 @@ pthread_mutex_t mutex_web_server = PTHREAD_MUTEX_INITIALIZER;
 
 int handle_type = HANDLE_WAITING;
 
-void remove_port_number()
-{
-	string ports;
-	string chk_fname = FLMSG_dir;
-	chk_fname.append("port_names.txt");
-	ifstream rchkfile(chk_fname.c_str());
-	if (rchkfile) {
-		string pnbr;
-		rchkfile >> pnbr;
-		while (!rchkfile.eof()) {
-			ports.append(pnbr).append("\n");
-			rchkfile >> pnbr;
-		}
-		rchkfile.close();
-		size_t p = ports.find(flmsg_webserver_szportnbr);
-		if (p != string::npos) ports.erase(p, 5);
-		ofstream wchkfile(chk_fname.c_str());
-		if (wchkfile) {
-			wchkfile << ports;
-			wchkfile.close();
-		}
-	}
-	LOG_INFO("Closed Web server on localhost:%s", flmsg_webserver_szportnbr);
-}
-
-bool get_next_port_number()
-{
-	string ports;
-	string chk_fname = FLMSG_dir;
-	chk_fname.append("port_names.txt");
-	ifstream rchkfile(chk_fname.c_str());
-	if (rchkfile) {
-		string pnbr;
-		rchkfile >> pnbr;
-		while (!rchkfile.eof()) {
-			ports.append(pnbr).append("\n");
-			rchkfile >> pnbr;
-		}
-		rchkfile.close();
-		if (ports.empty()) {
-			ports = "8080\n";
-			flmsg_webserver_portnbr = 8080;
-			strcpy(flmsg_webserver_szportnbr, "8080");
-		} else {
-			flmsg_webserver_portnbr = 8080;
-			snprintf(flmsg_webserver_szportnbr, 
-					sizeof(flmsg_webserver_szportnbr),
-					"%d", flmsg_webserver_portnbr);
-			while (ports.find(flmsg_webserver_szportnbr) != string::npos) {
-				flmsg_webserver_portnbr++;
-				snprintf(flmsg_webserver_szportnbr, 
-						sizeof(flmsg_webserver_szportnbr),
-						"%d", flmsg_webserver_portnbr);
-			}
-			if (flmsg_webserver_portnbr <= 8130)
-				ports.append(flmsg_webserver_szportnbr).append("\n");
-			else {
-				fl_alert2("Exceeded max web port 8130");
-				return false;
-			}
-		}
-		ofstream wchkfile(chk_fname.c_str());
-		if (wchkfile) {
-			wchkfile << ports;
-			wchkfile.close();
-		}
-	} else {
-		ports = "8080\n";
-		flmsg_webserver_portnbr = 8080;
-		strcpy(flmsg_webserver_szportnbr, "8080");
-		ofstream wchkfile(chk_fname.c_str());
-		if (wchkfile) {
-			wchkfile << ports;
-			wchkfile.close();
-		}
-	}
-	return true;
-}
-
-
 static const char *html_waiting =
   "<html><body>\n\
 	Custom form not posted<br>\n\
@@ -2762,7 +2708,6 @@ void close_server()
 	pthread_mutex_lock(&mutex_web_server);
 	exit_server = true;
 	pthread_mutex_unlock(&mutex_web_server);
-	remove_port_number();
 	MilliSleep(200);
 }
 
@@ -2788,27 +2733,53 @@ static int web_handler(struct mg_connection *conn)
 	return MG_REQUEST_PROCESSED;
 }
 
-void start_web_server()
+extern char *mg_open_msg;
+int start_web_server()
 {
 	if ((server = mg_create_server(NULL)) == NULL) {
 		fl_alert2("%s", "Failed to start web server");
-		return;
+		exit(EXIT_FAILURE);
+		return 0;
 	}
 
-	const char *msg = mg_set_option(server, "document_root", CUSTOM_dir.c_str());
+	mongoose_msgs.clear();
+	char retmsg[500];
+	int ret = mg_set_option(server, "document_root", CUSTOM_dir.c_str(), retmsg);
 
-	if (msg != NULL) {
+	if (ret) {
 		fl_alert2("%s", "Failed to set file server root directory");
-		return;
+		exit(EXIT_FAILURE);
+		return 0;
 	}
 
-	msg = mg_set_option(server, "listening_port", flmsg_webserver_szportnbr);
-	if (msg) {
-		LOG_ERROR("%s %s", msg, flmsg_webserver_szportnbr);
-		fl_alert2("Failed to open web server port %s", flmsg_webserver_szportnbr);
-		return;
-	}
+	int last_portnbr = srvr_portnbr + 100;
+	int test_portnbr = srvr_portnbr;
+	while (test_portnbr < last_portnbr) {
+		snprintf(sz_srvr_portnbr, sizeof(sz_srvr_portnbr),
+				"%d", test_portnbr);
+		ret = mg_set_option(server, "listening_port", sz_srvr_portnbr, retmsg);
 
+		if (ret == 0) break;
+		mongoose_msgs.append(retmsg).append(" ")
+					 .append(sz_srvr_portnbr);
+
+		test_portnbr++;
+		Fl::awake();
+	}
+	if (test_portnbr == last_portnbr) {
+		LOG_ERROR("%s", mongoose_msgs.c_str());
+		fl_alert2(
+"Web server port bind failed.\n\
+Range %d - %d", srvr_portnbr, last_portnbr - 1);
+		exit(EXIT_FAILURE);
+		return 0;
+	}
+	else {
+		if (!mongoose_msgs.empty()) mongoose_msgs.append("\n");
+		mongoose_msgs.append("Listening on port ").
+					  append(sz_srvr_portnbr);
+	}
+	
 	mg_set_request_handler(server, web_handler);
 
 	web_server_thread = new pthread_t;
@@ -2817,6 +2788,7 @@ void start_web_server()
 		exit(EXIT_FAILURE);
 	}
 
-	LOG_INFO("Web server on localhost:%s", flmsg_webserver_szportnbr);
-
+    return 1;
 }
+
+
