@@ -1,22 +1,22 @@
-// =====================================================================
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// hics203.cxx
+// This file is part of flmsg
 //
-// Author: Dave Freese, W1HKJ
-// Copyright: 2010
+// flrig is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// flrig is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
-//
-// =====================================================================
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include <stdlib.h>
 #include <iostream>
@@ -109,7 +109,7 @@ string hics203_tag_planning_chief			= ":planning_chief:";
 string hics203_tag_res_unit					= ":res_unit:";
 string hics203_tag_sit_unit					= ":sit_unit:";
 string hics203_tag_doc_unit					= ":doc_unit:";
-string hics203_tag_dem_unit				= ":dem_unit:";
+string hics203_tag_dem_unit					= ":dem_unit:";
 string hics203_tag_planning_other			= ":planning_other:";
 
 string hics203_tag_log_chief				= ":log_chief:";
@@ -229,6 +229,92 @@ void clear_hics203fields()
 	}
 }
 
+bool check_hics203fields()
+{
+	if (hics203_incident != txt_hics203_incident->value())
+		return true;
+	if (hics203_date != txt_hics203_date->value())
+		return true;
+	if (hics203_time != txt_hics203_time->value())
+		return true;
+	if (hics203_op_period != txt_hics203_op_period->value())
+		return true;
+	if (hics203_incident_commander != txt_hics203_incident_commander->value())
+		return true;
+	if (hics203_incident_safety_officer != txt_hics203_incident_safety_officer->value())
+		return true;
+	if (hics203_incident_info_officer != txt_hics203_incident_info_officer->value())
+		return true;
+	if (hics203_liaison_officer != txt_hics203_liaison_officer->value())
+		return true;
+	if (hics203_prepared_by != txt_hics203_prepared_by->value())
+		return true;
+	if (hics203_facility != txt_hics203_facility->value())
+		return true;
+	if (hics203_planning_chief != txt_hics203_planning_chief->value())
+		return true;
+	if (hics203_planning_other != txt_hics203_planning_other->value())
+		return true;
+	if (hics203_res_unit != txt_hics203_res_unit->value())
+		return true;
+	if (hics203_sit_unit != txt_hics203_sit_unit->value())
+		return true;
+	if (hics203_doc_unit != txt_hics203_doc_unit->value())
+		return true;
+	if (hics203_dem_unit != txt_hics203_dem_unit->value())
+		return true;
+	if (hics203_log_chief != txt_hics203_log_chief->value())
+		return true;
+	if (hics203_log_other != txt_hics203_log_other->value())
+		return true;
+	if (hics203_log_sup_brch != txt_hics203_log_sup_brch->value())
+		return true;
+	if (hics203_bus_brch != txt_hics203_bus_brch->value())
+		return true;
+	if (hics203_stg_mgr != txt_hics203_stg_mgr->value())
+		return true;
+	if (hics203_med_care_brch != txt_hics203_med_care_brch->value())
+		return true;
+	if (hics203_infr_brch != txt_hics203_infr_brch->value())
+		return true;
+	if (hics203_sec_brch != txt_hics203_sec_brch->value())
+		return true;
+	if (hics203_hazmat_brch != txt_hics203_hazmat_brch->value())
+		return true;
+	if (hics203_hcc_agency != txt_hics203_hcc_agency->value())
+		return true;
+	if (hics203_svc_brch != txt_hics203_svc_brch->value())
+		return true;
+	if (hics203_hcc_rep != txt_hics203_hcc_rep->value())
+		return true;
+	if (hics203_ext_loc != txt_hics203_ext_loc->value())
+		return true;
+	if (hics203_ext_rep != txt_hics203_ext_rep->value())
+		return true;
+	if (hics203_ops_chief != txt_hics203_ops_chief->value())
+		return true;
+	if (hics203_ops_other != txt_hics203_ops_other->value())
+		return true;
+	if (hics203_fin_chief != txt_hics203_fin_chief->value())
+		return true;
+	if (hics203_fin_other != txt_hics203_fin_other->value())
+		return true;
+	if (hics203_time_unit != txt_hics203_time_unit->value())
+		return true;
+	if (hics203_proc_unit != txt_hics203_proc_unit->value())
+		return true;
+	if (hics203_comp_unit != txt_hics203_comp_unit->value())
+		return true;
+	if (hics203_cost_unit != txt_hics203_cost_unit->value())
+		return true;
+
+	for (int i = 0; i < 6; i++) {
+		if (hics203_tech_spc[i] != txt_hics203_tech_spc[i]->value())
+			return true;
+	}
+	return false;
+}
+
 void update_hics203fields()
 {
 	hics203_incident = txt_hics203_incident->value();
@@ -379,52 +465,53 @@ string &hics_n(string & subst, int n)
 	return subst;
 }
 
-void make_hics_buff203()
+void make_hics_buff203(bool compress = false)
 {
-	update_hics203fields();
-
-	hics_buff203.append( lineout( hics203_tag_incident, hics203_incident ) );
-	hics_buff203.append( lineout( hics203_tag_date, hics203_date ) );
-	hics_buff203.append( lineout( hics203_tag_time, hics203_time ) );
-	hics_buff203.append( lineout( hics203_tag_op_period, hics203_op_period ) );
-	hics_buff203.append( lineout( hics203_tag_incident_commander, hics203_incident_commander ) );
-	hics_buff203.append( lineout( hics203_tag_incident_safety_officer, hics203_incident_safety_officer ) );
-	hics_buff203.append( lineout( hics203_tag_incident_info_officer, hics203_incident_info_officer ) );
-	hics_buff203.append( lineout( hics203_tag_liaison_officer, hics203_liaison_officer ) );
-	hics_buff203.append( lineout( hics203_tag_prepared_by, hics203_prepared_by ) );
-	hics_buff203.append( lineout( hics203_tag_facility, hics203_facility ) );
-	hics_buff203.append( lineout( hics203_tag_planning_chief, hics203_planning_chief ) );
-	hics_buff203.append( lineout( hics203_tag_planning_other, hics203_planning_other ) );
-	hics_buff203.append( lineout( hics203_tag_res_unit, hics203_res_unit ) );
-	hics_buff203.append( lineout( hics203_tag_sit_unit, hics203_sit_unit ) );
-	hics_buff203.append( lineout( hics203_tag_doc_unit, hics203_doc_unit ) );
-	hics_buff203.append( lineout( hics203_tag_dem_unit, hics203_dem_unit ) );
-	hics_buff203.append( lineout( hics203_tag_log_chief, hics203_log_chief ) );
-	hics_buff203.append( lineout( hics203_tag_log_other, hics203_log_other ) );
-	hics_buff203.append( lineout( hics203_tag_sup_brch, hics203_log_sup_brch ) );
-	hics_buff203.append( lineout( hics203_tag_bus_brch, hics203_bus_brch ) );
-	hics_buff203.append( lineout( hics203_tag_stg_mgr, hics203_stg_mgr ) );
-	hics_buff203.append( lineout( hics203_tag_med_care_brch, hics203_med_care_brch ) );
-	hics_buff203.append( lineout( hics203_tag_infr_brch, hics203_infr_brch ) );
-	hics_buff203.append( lineout( hics203_tag_sec_brch, hics203_sec_brch ) );
-	hics_buff203.append( lineout( hics203_tag_hazmat_brch, hics203_hazmat_brch ) );
-	hics_buff203.append( lineout( hics203_tag_hcc_agency, hics203_hcc_agency ) );
-	hics_buff203.append( lineout( hics203_tag_svc_brch, hics203_svc_brch ) );
-	hics_buff203.append( lineout( hics203_tag_hcc_rep, hics203_hcc_rep ) );
-	hics_buff203.append( lineout( hics203_tag_ext_loc, hics203_ext_loc ) );
-	hics_buff203.append( lineout( hics203_tag_ext_rep, hics203_ext_rep ) );
-	hics_buff203.append( lineout( hics203_tag_ops_chief, hics203_ops_chief ) );
-	hics_buff203.append( lineout( hics203_tag_ops_other, hics203_ops_other ) );
-	hics_buff203.append( lineout( hics203_tag_fin_chief, hics203_fin_chief ) );
-	hics_buff203.append( lineout( hics203_tag_fin_other, hics203_fin_other ) );
-	hics_buff203.append( lineout( hics203_tag_time_unit, hics203_time_unit ) );
-	hics_buff203.append( lineout( hics203_tag_proc_unit, hics203_proc_unit ) );
-	hics_buff203.append( lineout( hics203_tag_comp_unit, hics203_comp_unit ) );
-	hics_buff203.append( lineout( hics203_tag_cost_unit, hics203_cost_unit ) );
+	string mbuff;
+	mbuff.assign( lineout( hics203_tag_incident, hics203_incident ) );
+	mbuff.append( lineout( hics203_tag_date, hics203_date ) );
+	mbuff.append( lineout( hics203_tag_time, hics203_time ) );
+	mbuff.append( lineout( hics203_tag_op_period, hics203_op_period ) );
+	mbuff.append( lineout( hics203_tag_incident_commander, hics203_incident_commander ) );
+	mbuff.append( lineout( hics203_tag_incident_safety_officer, hics203_incident_safety_officer ) );
+	mbuff.append( lineout( hics203_tag_incident_info_officer, hics203_incident_info_officer ) );
+	mbuff.append( lineout( hics203_tag_liaison_officer, hics203_liaison_officer ) );
+	mbuff.append( lineout( hics203_tag_prepared_by, hics203_prepared_by ) );
+	mbuff.append( lineout( hics203_tag_facility, hics203_facility ) );
+	mbuff.append( lineout( hics203_tag_planning_chief, hics203_planning_chief ) );
+	mbuff.append( lineout( hics203_tag_planning_other, hics203_planning_other ) );
+	mbuff.append( lineout( hics203_tag_res_unit, hics203_res_unit ) );
+	mbuff.append( lineout( hics203_tag_sit_unit, hics203_sit_unit ) );
+	mbuff.append( lineout( hics203_tag_doc_unit, hics203_doc_unit ) );
+	mbuff.append( lineout( hics203_tag_dem_unit, hics203_dem_unit ) );
+	mbuff.append( lineout( hics203_tag_log_chief, hics203_log_chief ) );
+	mbuff.append( lineout( hics203_tag_log_other, hics203_log_other ) );
+	mbuff.append( lineout( hics203_tag_sup_brch, hics203_log_sup_brch ) );
+	mbuff.append( lineout( hics203_tag_bus_brch, hics203_bus_brch ) );
+	mbuff.append( lineout( hics203_tag_stg_mgr, hics203_stg_mgr ) );
+	mbuff.append( lineout( hics203_tag_med_care_brch, hics203_med_care_brch ) );
+	mbuff.append( lineout( hics203_tag_infr_brch, hics203_infr_brch ) );
+	mbuff.append( lineout( hics203_tag_sec_brch, hics203_sec_brch ) );
+	mbuff.append( lineout( hics203_tag_hazmat_brch, hics203_hazmat_brch ) );
+	mbuff.append( lineout( hics203_tag_hcc_agency, hics203_hcc_agency ) );
+	mbuff.append( lineout( hics203_tag_svc_brch, hics203_svc_brch ) );
+	mbuff.append( lineout( hics203_tag_hcc_rep, hics203_hcc_rep ) );
+	mbuff.append( lineout( hics203_tag_ext_loc, hics203_ext_loc ) );
+	mbuff.append( lineout( hics203_tag_ext_rep, hics203_ext_rep ) );
+	mbuff.append( lineout( hics203_tag_ops_chief, hics203_ops_chief ) );
+	mbuff.append( lineout( hics203_tag_ops_other, hics203_ops_other ) );
+	mbuff.append( lineout( hics203_tag_fin_chief, hics203_fin_chief ) );
+	mbuff.append( lineout( hics203_tag_fin_other, hics203_fin_other ) );
+	mbuff.append( lineout( hics203_tag_time_unit, hics203_time_unit ) );
+	mbuff.append( lineout( hics203_tag_proc_unit, hics203_proc_unit ) );
+	mbuff.append( lineout( hics203_tag_comp_unit, hics203_comp_unit ) );
+	mbuff.append( lineout( hics203_tag_cost_unit, hics203_cost_unit ) );
 
 	for (int i = 0; i < 6; i++) {
-		hics_buff203.append( lineout( hics_n( hics203_tag_tech_spc, i ), hics203_tech_spc[i] ) );
+		mbuff.append( lineout( hics_n( hics203_tag_tech_spc, i ), hics203_tech_spc[i] ) );
 	}
+	if (compress) compress_maybe(mbuff);
+	hics_buff203.append(mbuff);
 }
 
 void read_hics203_buffer(string data)
@@ -479,6 +566,12 @@ void read_hics203_buffer(string data)
 
 void cb_hics203_new()
 {
+	if (check_hics203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
+			update_header(CHANGED);
+			cb_hics203_save();
+		}
+	}
 	clear_hics203_form();
 	clear_header();
 	def_hics203_filename = ICS_msg_dir;
@@ -507,10 +600,34 @@ void cb_hics203_wrap_import(string wrapfilename, string inpbuffer)
 	using_hics203_template = false;
 }
 
+int eval_hics203_fsize()
+{
+	Ccrc16 chksum;
+	evalstr.assign("[WRAP:beg][WRAP:lf][WRAP:fn ");
+	evalstr.append(base_hics203_filename).append("]");
+	update_hics203fields();
+	update_header(FROM);
+	evalstr.append(header("<hics203>"));
+	hics_buff203.clear();
+	make_hics_buff203(true);
+	if (hics_buff203.empty()) return 0;
+	compress_maybe( hics_buff203 );
+	evalstr.append( hics_buff203 );
+	evalstr.append("[WRAP:chksum ").append(chksum.scrc16(evalstr)).append("][WRAP:end]");
+	return evalstr.length();
+}
+
 void cb_hics203_wrap_export()
 {
+	if (check_hics203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_hics203fields();
+
 	if (base_hics203_filename == "new"HF203_EXT || base_hics203_filename == "default"HF203_EXT)
-		cb_hics203_save_as();
+		if (!cb_hics203_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
 	wrapfilename.append(base_hics203_filename);
@@ -522,26 +639,37 @@ void cb_hics203_wrap_export()
 	if (p) {
 		string pext = fl_filename_ext(p);
 		wrapfilename = p;
-		update_header(true);
-		hics_buff203.assign(header("<hics203>", true, true));
-		make_hics_buff203();
+		update_header(FROM);
+		hics_buff203.assign(header("<hics203>"));
+		make_hics_buff203(true);
 		export_wrapfile(base_hics203_filename, wrapfilename, hics_buff203, pext != ".wrap");
+
+		hics_buff203.assign(header("<hics203>"));
+		make_hics_buff203(false);
+		write_hics203(def_hics203_filename);
 	}
 }
 
 void cb_hics203_wrap_autosend()
 {
-	if (base_hics203_filename == "new"HF203_EXT || 
-		base_hics203_filename == "default"HF203_EXT ||
-		using_hics203_template == true)
+	if (check_hics203fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_hics203fields();
+
+	if (base_hics203_filename == "new"HF203_EXT || base_hics203_filename == "default"HF203_EXT)
 		cb_hics203_save_as();
 
-	string wrapfilename = WRAP_auto_dir;
-	wrapfilename.append("wrap_auto_file");
-	update_header(true);
-	hics_buff203.assign(header("<hics203>", true, true));
-	make_hics_buff203();
-	export_wrapfile(base_hics203_filename, wrapfilename, hics_buff203, false);
+	update_header(FROM);
+	hics_buff203.assign(header("<hics203>"));
+	make_hics_buff203(true);
+	xfr_via_socket(base_hics203_filename, hics_buff203);
+
+	hics_buff203.assign(header("<hics203>"));
+	make_hics_buff203(false);
+	write_hics203(def_hics203_filename);
 }
 
 void cb_hics203_load_template()
@@ -572,7 +700,10 @@ void cb_hics203_save_template()
 			"Template file\t*"HT203_EXT,
 			def_hics203_filename.c_str());
 	if (p) {
-		clear_header();
+		update_header(CHANGED);
+		update_203fields();
+		hics_buff203.assign(header("<hics203>"));
+		make_hics_buff203();
 		write_hics203(p);
 	}
 }
@@ -590,6 +721,10 @@ void cb_hics203_save_as_template()
 		if (strlen(pext) == 0) def_hics203_TemplateName.append(HT203_EXT);
 		remove_spaces_from_filename(def_hics203_TemplateName);
 		clear_header();
+		update_header(CHANGED);
+		update_203fields();
+		hics_buff203.assign(header("<hics203>"));
+		make_hics_buff203();
 		write_hics203(def_hics203_TemplateName);
 		show_filename(def_hics203_TemplateName);
 		using_hics203_template = true;
@@ -613,14 +748,12 @@ void write_hics203(string s)
 {
 	FILE *file203 = fopen(s.c_str(), "w");
 	if (!file203) return;
-	update_header();
-	hics_buff203.assign(save_header("<hics203>"));
-	make_hics_buff203();
+
 	fwrite(hics_buff203.c_str(), hics_buff203.length(), 1, file203);
 	fclose(file203);
 }
 
-void cb_hics203_save_as()
+bool cb_hics203_save_as()
 {
 	const char *p;
 	string newfilename;
@@ -635,8 +768,10 @@ void cb_hics203_save_as()
 
 	p = FSEL::saveas(_("Save data file"), "HICS-203\t*"HF203_EXT,
 					newfilename.c_str());
-	if (!p) return;
-	if (strlen(p) == 0) return;
+
+	if (!p) return false;
+	if (strlen(p) == 0) return false;
+
 	if (progStatus.sernbr_fname) {
 		string haystack = p;
 		if (haystack.find(newfilename) != string::npos) {
@@ -655,13 +790,15 @@ void cb_hics203_save_as()
 	if (strlen(pext) == 0) def_hics203_filename.append(HF203_EXT);
 
 	remove_spaces_from_filename(def_hics203_filename);
-	clear_header();
-	update_header();
-	hics_buff203.assign(save_header("<hics203>"));
+	update_hics203fields();
+	update_header(NEW);
+	hics_buff203.assign(header("<hics203>"));
+	make_hics_buff203();
 	write_hics203(def_hics203_filename);
 
 	using_hics203_template = false;
 	show_filename(def_hics203_filename);
+	return true;
 }
 
 void cb_hics203_save()
@@ -672,8 +809,10 @@ void cb_hics203_save()
 		cb_hics203_save_as();
 		return;
 	}
-	update_header();
-	hics_buff203.assign(save_header("<hics203>"));
+	if (check_hics203fields()) update_header(CHANGED);
+	update_hics203fields();
+	hics_buff203.assign(header("<hics203>"));
+	make_hics_buff203();
 	write_hics203(def_hics203_filename);
 	using_hics203_template = false;
 }
