@@ -5,16 +5,20 @@
 //  Author(s):
 //    Robert Stiles, KK5VD, Copyright (C) 2013
 //
+// This file is part of FLAMP.
+//
+// This is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
 // This software is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 // =====================================================================
 
@@ -25,6 +29,12 @@
 #include <string>
 #include <cstring>
 
+extern int mode_table_count(void);
+extern char * modem_at_index(int index);
+
+extern bool modem_available(std::string modem);
+extern bool modem_available(char *modem, int search_limit);
+
 extern float seconds_from_c_string(const char *mode, const char *string, int length, float *overhead);
 extern float minutes_from_c_string(const char *mode, const char *string, int length, float *overhead);
 
