@@ -1,22 +1,22 @@
-// =====================================================================
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// mars_net.cxx
+// This file is part of flmsg
 //
-// Author: Dave Freese, W1HKJ
-// Copyright: 2010
+// flrig is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// flrig is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  It is
-// copyright under the GNU General Public License.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
-//
-// =====================================================================
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include <stdlib.h>
 #include <iostream>
@@ -72,7 +72,7 @@
 
 using namespace std;
 
-const char mars_net_precedent[] = "RPIFM";
+const char mars_net_precedent[] = "RPOZ";
 
 string buffnet;
 string def_mars_net_filename = "";
@@ -109,7 +109,7 @@ string mars_net_COMMENTS	= ":comments:";
 
 string s_mars_net_DE;
 string s_mars_net_NBR;
-string s_mars_net_PREC;
+string s_mars_net_PREC = "R";
 string s_mars_net_DTG;
 string s_mars_net_FMNAME;
 string s_mars_net_FMCALL;
@@ -151,7 +151,7 @@ void clear_mars_net_fields()
 {
 	s_mars_net_DE.clear();
 	s_mars_net_NBR.clear();
-	s_mars_net_PREC = "M";
+	s_mars_net_PREC = "R";
 	s_mars_net_DTG.clear();
 	s_mars_net_FMNAME.clear();
 	s_mars_net_FMCALL.clear();
@@ -176,12 +176,43 @@ void clear_mars_net_fields()
 
 }
 
+bool check_mars_net_fields()
+{
+	string temp;
+	if (s_mars_net_DE != txt_mars_net_DE->value()) return true;
+	if (s_mars_net_NBR != txt_mars_net_NBR->value()) return true;
+	temp = mars_net_precedent[sel_mars_net_PREC->index()];
+	if (s_mars_net_PREC != temp) return true;
+	if (s_mars_net_DTG != txt_mars_net_DTG->value()) return true;
+	if (s_mars_net_FMNAME != txt_mars_net_FMNAME->value()) return true;
+	if (s_mars_net_FMCALL != txt_mars_net_FMCALL->value()) return true;
+	if (s_mars_net_FMSTATE != txt_mars_net_FMSTATE->value()) return true;
+	if (s_mars_net_TOPOS != txt_mars_net_TOPOS->value()) return true;
+	if (s_mars_net_TOCALL != txt_mars_net_TOCALL->value()) return true;
+	if (s_mars_net_TOSTATE != txt_mars_net_TOSTATE->value()) return true;
+	if (s_mars_net_INFOPOS != txt_mars_net_INFOPOS->value()) return true;
+	if (s_mars_net_INFOCALL != txt_mars_net_INFOCALL->value()) return true;
+	if (s_mars_net_INFOSTATE != txt_mars_net_INFOSTATE->value()) return true;
+	if (s_mars_net_INCIDENT != txt_mars_net_INCIDENT->value()) return true;
+	if (s_mars_net_DND != txt_mars_net_DND->value()) return true;
+	if (s_mars_net_NETCALL != txt_mars_net_NETCALL->value()) return true;
+	if (s_mars_net_DTGSTART != txt_mars_net_DTGSTART->value()) return true;
+	if (s_mars_net_DTGEND != txt_mars_net_DTGEND->value()) return true;
+	if (s_mars_net_NETSB != txt_mars_net_NETSB->value()) return true;
+	if (s_mars_net_NCSCALL != txt_mars_net_NCSCALL->value()) return true;
+	if (s_mars_net_NBRSTAS != txt_mars_net_NBRSTAS->value()) return true;
+	if (s_mars_net_CALLS != txt_mars_net_CALLS->value()) return true;
+	if (s_mars_net_NBRMSGS != txt_mars_net_NBRMSGS->value()) return true;
+	if (s_mars_net_COMMENTS != txt_mars_net_COMMENTS->value()) return true;
+	return false;
+}
+
 void update_mars_net_fields()
 {
 	s_mars_net_DE = txt_mars_net_DE->value();
 	s_mars_net_NBR = txt_mars_net_NBR->value();
 	s_mars_net_PREC.clear();
-	s_mars_net_PREC = mars_net_precedent[sel_mars_net_PREC->value()];
+	s_mars_net_PREC = mars_net_precedent[sel_mars_net_PREC->index()];
 	s_mars_net_DTG = txt_mars_net_DTG->value();
 	s_mars_net_FMNAME = txt_mars_net_FMNAME->value();
 	s_mars_net_FMCALL = txt_mars_net_FMCALL->value();
@@ -213,7 +244,7 @@ void update_mars_netform()
 	size_t n = strchr(mars_net_precedent, s_mars_net_PREC[0]) - mars_net_precedent;
 	if (n < 0) n = 0;
 	if (n > 4) n = 4;
-	sel_mars_net_PREC->value(n);
+	sel_mars_net_PREC->index(n);
 
 	txt_mars_net_DTG->value(s_mars_net_DTG.c_str());
 	txt_mars_net_FMNAME->value(s_mars_net_FMNAME.c_str());
@@ -243,7 +274,7 @@ void clear_mars_net_form()
 	clear_mars_net_fields();
 	txt_mars_net_DE->value("");
 	txt_mars_net_NBR->value("");
-	sel_mars_net_PREC->value(4);
+	sel_mars_net_PREC->index(4);
 	txt_mars_net_DTG->value("");
 	txt_mars_net_FMNAME->value("");
 	txt_mars_net_FMCALL->value("");
@@ -265,39 +296,38 @@ void clear_mars_net_form()
 	txt_mars_net_CALLS->value("");
 	txt_mars_net_NBRMSGS->value("");
 	txt_mars_net_COMMENTS->value("");
-
 }
 
-void make_mars_buffnet()
+void make_mars_buffnet(bool compress = false)
 {
-	update_mars_net_fields();
-	buffnet = header("<mars_net>");
-
-	buffnet.append( lineout( mars_net_DE, s_mars_net_DE ) );
-	buffnet.append( lineout( mars_net_NBR, s_mars_net_NBR ) );
-	buffnet.append( lineout( mars_net_PREC, s_mars_net_PREC ) );
-	buffnet.append( lineout( mars_net_DTG, s_mars_net_DTG ) );
-	buffnet.append( lineout( mars_net_FMNAME, s_mars_net_FMNAME ) );
-	buffnet.append( lineout( mars_net_FMCALL, s_mars_net_FMCALL ) );
-	buffnet.append( lineout( mars_net_FMSTATE, s_mars_net_FMSTATE ) );
-	buffnet.append( lineout( mars_net_TOPOS, s_mars_net_TOPOS ) );
-	buffnet.append( lineout( mars_net_TOCALL, s_mars_net_TOCALL ) );
-	buffnet.append( lineout( mars_net_TOSTATE, s_mars_net_TOSTATE ) );
-	buffnet.append( lineout( mars_net_INFOPOS, s_mars_net_INFOPOS ) );
-	buffnet.append( lineout( mars_net_INFOCALL, s_mars_net_INFOCALL ) );
-	buffnet.append( lineout( mars_net_INFOSTATE, s_mars_net_INFOSTATE ) );
-	buffnet.append( lineout( mars_net_INCIDENT, s_mars_net_INCIDENT ) );
-	buffnet.append( lineout( mars_net_DND, s_mars_net_DND ) );
-	buffnet.append( lineout( mars_net_NETCALL, s_mars_net_NETCALL ) );
-	buffnet.append( lineout( mars_net_DTGSTART, s_mars_net_DTGSTART ) );
-	buffnet.append( lineout( mars_net_DTGEND, s_mars_net_DTGEND ) );
-	buffnet.append( lineout( mars_net_NETSB, s_mars_net_NETSB ) );
-	buffnet.append( lineout( mars_net_NCSCALL, s_mars_net_NCSCALL ) );
-	buffnet.append( lineout( mars_net_NBRSTAS, s_mars_net_NBRSTAS ) );
-	buffnet.append( lineout( mars_net_CALLS, s_mars_net_CALLS ) );
-	buffnet.append( lineout( mars_net_NBRMSGS, s_mars_net_NBRMSGS ) );
-	buffnet.append( lineout( mars_net_COMMENTS, s_mars_net_COMMENTS ) );
-
+	string mbuff;
+	mbuff.clear();
+	mbuff.append( lineout( mars_net_DE, s_mars_net_DE ) );
+	mbuff.append( lineout( mars_net_NBR, s_mars_net_NBR ) );
+	mbuff.append( lineout( mars_net_PREC, s_mars_net_PREC ) );
+	mbuff.append( lineout( mars_net_DTG, s_mars_net_DTG ) );
+	mbuff.append( lineout( mars_net_FMNAME, s_mars_net_FMNAME ) );
+	mbuff.append( lineout( mars_net_FMCALL, s_mars_net_FMCALL ) );
+	mbuff.append( lineout( mars_net_FMSTATE, s_mars_net_FMSTATE ) );
+	mbuff.append( lineout( mars_net_TOPOS, s_mars_net_TOPOS ) );
+	mbuff.append( lineout( mars_net_TOCALL, s_mars_net_TOCALL ) );
+	mbuff.append( lineout( mars_net_TOSTATE, s_mars_net_TOSTATE ) );
+	mbuff.append( lineout( mars_net_INFOPOS, s_mars_net_INFOPOS ) );
+	mbuff.append( lineout( mars_net_INFOCALL, s_mars_net_INFOCALL ) );
+	mbuff.append( lineout( mars_net_INFOSTATE, s_mars_net_INFOSTATE ) );
+	mbuff.append( lineout( mars_net_INCIDENT, s_mars_net_INCIDENT ) );
+	mbuff.append( lineout( mars_net_DND, s_mars_net_DND ) );
+	mbuff.append( lineout( mars_net_NETCALL, s_mars_net_NETCALL ) );
+	mbuff.append( lineout( mars_net_DTGSTART, s_mars_net_DTGSTART ) );
+	mbuff.append( lineout( mars_net_DTGEND, s_mars_net_DTGEND ) );
+	mbuff.append( lineout( mars_net_NETSB, s_mars_net_NETSB ) );
+	mbuff.append( lineout( mars_net_NCSCALL, s_mars_net_NCSCALL ) );
+	mbuff.append( lineout( mars_net_NBRSTAS, s_mars_net_NBRSTAS ) );
+	mbuff.append( lineout( mars_net_CALLS, s_mars_net_CALLS ) );
+	mbuff.append( lineout( mars_net_NBRMSGS, s_mars_net_NBRMSGS ) );
+	mbuff.append( lineout( mars_net_COMMENTS, s_mars_net_COMMENTS ) );
+	if (compress) compress_maybe(mbuff);
+	buffnet.append(mbuff);
 }
 
 void read_mars_net_buffer(string data)
@@ -335,6 +365,12 @@ void read_mars_net_buffer(string data)
 
 void cb_mars_net_new()
 {
+	if (check_mars_net_fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 1) {
+			update_header(CHANGED);
+			cb_mars_net_save();
+		}
+	}
 	clear_mars_net_form();
 	def_mars_net_filename = ICS_msg_dir;
 	def_mars_net_filename.append("new"FMARSNET_EXT);
@@ -362,10 +398,34 @@ void cb_mars_net_wrap_import(string wrapfilename, string inpbuffer)
 	using_mars_net_template = false;
 }
 
+int eval_mars_net_fsize()
+{
+	Ccrc16 chksum;
+	evalstr.assign("[WRAP:beg][WRAP:lf][WRAP:fn ");
+	evalstr.append(base_mars_net_filename).append("]");
+	update_mars_net_fields();
+	update_header(FROM);
+	evalstr.append(header("<mars_net>"));
+	buffnet.clear();
+	make_mars_buffnet(true);
+	if (buffnet.empty()) return 0;
+	compress_maybe( buffnet );
+	evalstr.append( buffnet );
+	evalstr.append("[WRAP:chksum ").append(chksum.scrc16(evalstr)).append("][WRAP:end]");
+	return evalstr.length();
+}
+
 void cb_mars_net_wrap_export()
 {
+	if (check_mars_net_fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_mars_net_fields();
+
 	if (base_mars_net_filename == "new"FMARSNET_EXT || base_mars_net_filename == "default"FMARSNET_EXT)
-		cb_mars_net_save_as();
+		if (!cb_mars_net_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
 	wrapfilename.append(base_mars_net_filename);
@@ -377,22 +437,38 @@ void cb_mars_net_wrap_export()
 	if (p) {
 		string pext = fl_filename_ext(p);
 		wrapfilename = p;
-		make_mars_buffnet();
+
+		update_header(FROM);
+		buffnet.assign(header("<mars_net>"));
+		make_mars_buffnet(true);
 		export_wrapfile(base_mars_net_filename, wrapfilename, buffnet, pext != ".wrap");
+
+		buffnet.assign(header("<mars_net>"));
+		make_mars_buffnet(false);
+		write_mars_net(def_mars_net_filename);
 	}
 }
 
 void cb_mars_net_wrap_autosend()
 {
-	if (base_mars_net_filename == "new"FMARSNET_EXT || 
-		base_mars_net_filename == "default"FMARSNET_EXT ||
-		using_mars_net_template == true)
-		cb_mars_net_save_as();
+	if (check_mars_net_fields()) {
+		if (fl_choice2("Form modified, save?", "No", "Yes", NULL) == 0)
+			return;
+		update_header(CHANGED);
+	}
+	update_mars_net_fields();
 
-	string wrapfilename = WRAP_auto_dir;
-	wrapfilename.append("wrap_auto_file");
-	make_mars_buffnet();
-	export_wrapfile(base_mars_net_filename, wrapfilename, buffnet, false);
+	if (base_mars_net_filename == "new"FMARSNET_EXT || base_mars_net_filename == "default"FMARSNET_EXT)
+		if (!cb_mars_net_save_as()) return;
+
+	update_header(FROM);
+	buffnet.assign(header("<mars_net>"));
+	make_mars_buffnet(true);
+	xfr_via_socket(base_mars_net_filename, buffnet);
+
+	buffnet.assign(header("<mars_net>"));
+	make_mars_buffnet(false);
+	write_mars_net(def_mars_net_filename);
 }
 
 void cb_mars_net_load_template()
@@ -422,8 +498,13 @@ void cb_mars_net_save_template()
 			"Save template file",
 			"Template file\t*"TMARSNET_EXT,
 			def_mars_net_filename.c_str());
-	if (p)
+	if (p) {
+		update_header(CHANGED);
+		update_mars_net_fields();
+		buffnet.assign(header("<mars_net>"));
+		make_mars_buffnet();
 		write_mars_net(p);
+	}
 }
 
 void cb_mars_net_save_as_template()
@@ -438,7 +519,14 @@ void cb_mars_net_save_as_template()
 		def_mars_net_TemplateName = p;
 		if (strlen(pext) == 0) def_mars_net_TemplateName.append(TMARSNET_EXT);
 		remove_spaces_from_filename(def_mars_net_TemplateName);
+
+		clear_header();
+		update_header(CHANGED);
+		update_mars_net_fields();
+		buffnet.assign(header("<mars_net>"));
+		make_mars_buffnet();
 		write_mars_net(def_mars_net_TemplateName);
+
 		show_filename(def_mars_net_TemplateName);
 		using_mars_net_template = true;
 	}
@@ -466,7 +554,7 @@ void write_mars_net(string s)
 	fclose(filenet);
 }
 
-void cb_mars_net_save_as()
+bool cb_mars_net_save_as()
 {
 	const char *p;
 	string newfilename;
@@ -481,8 +569,10 @@ void cb_mars_net_save_as()
 
 	p = FSEL::saveas(_("Save data file"), "ICS-net\t*"FMARSNET_EXT,
 					newfilename.c_str());
-	if (!p) return;
-	if (strlen(p) == 0) return;
+
+	if (!p) return false;
+	if (strlen(p) == 0) return false;
+
 	if (progStatus.sernbr_fname) {
 		string haystack = p;
 		if (haystack.find(newfilename) != string::npos) {
@@ -501,10 +591,16 @@ void cb_mars_net_save_as()
 	if (strlen(pext) == 0) def_mars_net_filename.append(FMARSNET_EXT);
 
 	remove_spaces_from_filename(def_mars_net_filename);
+
+	update_header(NEW);
+	update_mars_net_fields();
+	buffnet.assign(header("<mars_net>"));
+	make_mars_buffnet();
 	write_mars_net(def_mars_net_filename);
 
 	using_mars_net_template = false;
 	show_filename(def_mars_net_filename);
+	return true;
 }
 
 void cb_mars_net_save()
@@ -515,7 +611,12 @@ void cb_mars_net_save()
 		cb_mars_net_save_as();
 		return;
 	}
+	if (check_mars_net_fields()) update_header(CHANGED);
+	update_mars_net_fields();
+	buffnet.assign(header("<mars_net>"));
+	make_mars_buffnet();
 	write_mars_net(def_mars_net_filename);
+
 	using_mars_net_template = false;
 }
 
